LogTarget

Trait LogTarget 

pub trait LogTarget:
    Send
    + Sync
    + 'static {
    type Time: TimeAbstraction;

    // Required methods
    fn init();
    fn println(args: Arguments<'_>);
}
LogTarget is used to perform log-related operations in a platform-agnostic manner.

Required Associated Types

type Time: TimeAbstraction

A source of time to add into log messages.

Required Methods

fn init()

Initializes global state necessary for this type.

fn println(args: Arguments<'_>)

Outputs a line of text through this log target.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors